@@ -1,7 +1,15 @@
 `GEOTOPO` <-
-function(TOPO, PLOC, PROJ, calcol)
+function(TOPO, PLOC, PROJ, calcol=NULL, npoints=500)
   {
 
+
+    if(missing(calcol)) {  calcol = settopocol() }
+    if(missing(npoints)) { npoints=500  }
+
+
+     if(is.null(calcol)) {  calcol = settopocol() }
+
+    
     ZZ2 = subsetTOPO(TOPO, PLOC)
     d = dim(ZZ2$z)
     
@@ -25,8 +33,8 @@ function(TOPO, PLOC, PROJ, calcol)
     GXY  = GLOB.XY(G$y, G$x , PROJ  )
     
     
-    xo = seq(from=range(GXY$x)[1], to=range(GXY$x)[2], length=500)
-    yo = seq(from=range(GXY$y)[1], to=range(GXY$y)[2], length=500)
+    xo = seq(from=range(GXY$x)[1], to=range(GXY$x)[2], length=npoints)
+    yo = seq(from=range(GXY$y)[1], to=range(GXY$y)[2], length=npoints)
 
     IZ = interp(x=GXY$x , y=GXY$y,  z=t(ZZ2$z)  , xo=xo, yo=yo, extrap=FALSE)
 
@@ -70,6 +78,7 @@ function(TOPO, PLOC, PROJ, calcol)
     
     
     brs = c(calcol$z1[1], calcol$z2,  calcol$z2[length(calcol$z2)]+10000)
+    
     Cs = CZ
 
     naflag = which(is.na(Cs))
@@ -101,45 +110,51 @@ function(TOPO, PLOC, PROJ, calcol)
 ####      ltheta = 120, lphi=60, shade = 0.75, border = NA, expand=0.001, box = FALSE )
 
 
-    bluesrgb = col2rgb(blues)
+   if( all(is.na(UZ)) )
+     {
+       C2 = Collist
+     }
+   else
+     {
+       
+       bluesrgb = col2rgb(blues)
 
-    rngU = range(UZ[!is.na(UZ)])
-
-    ncol = 100
-    levs = seq(from=rngU[1], to=rngU[2], length=100)
-    
-
-    brs = levs
-    Cs = UZ[!is.na(UZ)]
-    fs = findInterval(Cs, brs)
-
-    
+       rngU = range(UZ[!is.na(UZ)])
+       
+       ncol = 100
+       levs = seq(from=rngU[1], to=rngU[2], length=100)
+       
+       
+       brs = levs
+       Cs = UZ[!is.na(UZ)]
+       fs = findInterval(Cs, brs)
+       
+       
 ####   df = diff(brs)
     
 ####  coldis = (Cs - brs[fs])/df[fs]
-
-
-    Anewcol = list(r=bluesrgb[1,fs],
-      g =bluesrgb[2,fs] ,
-      b =bluesrgb[3,fs] )
-
-
-    UCollist = rgb(Anewcol$r/255, Anewcol$g/255, Anewcol$b/255)
-
-    C2 = Collist
-    C2[!is.na(UZ)] = UCollist
-
-
-    Mollist = matrix(data=C2, ncol=dz[2], nrow=dz[1])
+       
+       
+       Anewcol = list(r=bluesrgb[1,fs],
+         g =bluesrgb[2,fs] ,
+         b =bluesrgb[3,fs] )
+       
+       
+       UCollist = rgb(Anewcol$r/255, Anewcol$g/255, Anewcol$b/255)
+       
+       C2 = Collist
+       C2[!is.na(UZ)] = UCollist
+       
+     }
     
-
+    Mollist = matrix(data=C2, ncol=dz[2], nrow=dz[1])
     
     dMOL = dim(Mollist)       
     
-
+    
     PMAT = persp(xo, yo, IZ$z, theta = 0, phi = 90, r=4000, col=Mollist[1:(dMOL[1]-1), 1:(dMOL[2]-1)] , scale = FALSE,
       ltheta = 120, lphi=60, shade = 0.75, border = NA, expand=0.001, box = FALSE )
-
+    
 
     
     
